.fill-sun[data-v-62705c46]{fill:rgb(var(--v-theme-sun))}.fill-grid[data-v-62705c46]{fill:rgb(var(--v-theme-grid))}.stroke-sun[data-v-62705c46]{stroke:rgb(var(--v-theme-sun))}.stroke-grid[data-v-62705c46]{stroke:rgb(var(--v-theme-grid))}
