import{m as h,o as I,c as f,b as B,d as E,f as $,g as W,i as z,h as A,k as F,l as O,x as g}from"./transition-cd9cc606.js";import{p as y,v as N,l as x,N as P,y as D,c as b,b as o,m as a,O as U,s as j,A as q}from"./index-5ee1411a.js";import{a as G}from"./index-a55adddd.js";import{V as J}from"./VImg-71612e97.js";const K=y({color:String,inset:Boolean,length:[Number,String],opacity:[Number,String],thickness:[Number,String],vertical:Boolean,...h(),...N()},"VDivider"),te=x()({name:"VDivider",props:K(),setup(e,s){let{attrs:t,slots:i}=s;const{themeClasses:n}=P(e),{textColorClasses:r,textColorStyles:d}=I(D(e,"color")),c=b(()=>{const l={};return e.length&&(l[e.vertical?"height":"width"]=o(e.length)),e.thickness&&(l[e.vertical?"borderRightWidth":"borderTopWidth"]=o(e.thickness)),l});return f(()=>{const l=a("hr",{class:[{"v-divider":!0,"v-divider--inset":e.inset,"v-divider--vertical":e.vertical},n.value,r.value,e.class],style:[c.value,d.value,{"--v-border-opacity":e.opacity},e.style],"aria-orientation":!t.role||t.role==="separator"?e.vertical?"vertical":"horizontal":void 0,role:`${t.role||"separator"}`},null);return i.default?a("div",{class:["v-divider__wrapper",{"v-divider__wrapper--vertical":e.vertical,"v-divider__wrapper--inset":e.inset}]},[l,a("div",{class:"v-divider__content"},[i.default()]),l]):l}),{}}});const L=y({text:String,...h(),...B()},"VToolbarTitle"),M=x()({name:"VToolbarTitle",props:L(),setup(e,s){let{slots:t}=s;return f(()=>{const i=!!(t.default||t.text||e.text);return a(e.tag,{class:["v-toolbar-title",e.class],style:e.style},{default:()=>{var n;return[i&&a("div",{class:"v-toolbar-title__placeholder"},[t.text?t.text():e.text,(n=t.default)==null?void 0:n.call(t)])]}})}),{}}}),Q=[null,"prominent","default","comfortable","compact"],X=y({absolute:Boolean,collapse:Boolean,color:String,density:{type:String,default:"default",validator:e=>Q.includes(e)},extended:Boolean,extensionHeight:{type:[Number,String],default:48},flat:Boolean,floating:Boolean,height:{type:[Number,String],default:64},image:String,title:String,...E(),...h(),...$(),...W(),...B({tag:"header"}),...N()},"VToolbar"),ae=x()({name:"VToolbar",props:X(),setup(e,s){var T;let{slots:t}=s;const{backgroundColorClasses:i,backgroundColorStyles:n}=z(D(e,"color")),{borderClasses:r}=A(e),{elevationClasses:d}=F(e),{roundedClasses:c}=O(e),{themeClasses:l}=P(e),{rtlClasses:R}=U(),u=j(!!(e.extended||(T=t.extension)!=null&&T.call(t))),v=b(()=>parseInt(Number(e.height)+(e.density==="prominent"?Number(e.height):0)-(e.density==="comfortable"?8:0)-(e.density==="compact"?16:0),10)),m=b(()=>u.value?parseInt(Number(e.extensionHeight)+(e.density==="prominent"?Number(e.extensionHeight):0)-(e.density==="comfortable"?4:0)-(e.density==="compact"?8:0),10):0);return q({VBtn:{variant:"text"}}),f(()=>{var k;const w=!!(e.title||t.title),H=!!(t.image||e.image),V=(k=t.extension)==null?void 0:k.call(t);return u.value=!!(e.extended||V),a(e.tag,{class:["v-toolbar",{"v-toolbar--absolute":e.absolute,"v-toolbar--collapse":e.collapse,"v-toolbar--flat":e.flat,"v-toolbar--floating":e.floating,[`v-toolbar--density-${e.density}`]:!0},i.value,r.value,d.value,c.value,l.value,R.value,e.class],style:[n.value,e.style]},{default:()=>[H&&a("div",{key:"image",class:"v-toolbar__image"},[t.image?a(g,{key:"image-defaults",disabled:!e.image,defaults:{VImg:{cover:!0,src:e.image}}},t.image):a(J,{key:"image-img",cover:!0,src:e.image},null)]),a(g,{defaults:{VTabs:{height:o(v.value)}}},{default:()=>{var _,C,S;return[a("div",{class:"v-toolbar__content",style:{height:o(v.value)}},[t.prepend&&a("div",{class:"v-toolbar__prepend"},[(_=t.prepend)==null?void 0:_.call(t)]),w&&a(M,{key:"title",text:e.title},{text:t.title}),(C=t.default)==null?void 0:C.call(t),t.append&&a("div",{class:"v-toolbar__append"},[(S=t.append)==null?void 0:S.call(t)])])]}}),a(g,{defaults:{VTabs:{height:o(m.value)}}},{default:()=>[a(G,null,{default:()=>[u.value&&a("div",{class:"v-toolbar__extension",style:{height:o(m.value)}},[V])]})]})]})}),{contentHeight:v,extensionHeight:m}}});export{ae as V,te as a};
