import{B as v,ay as f,c as g,q as c,D as _,m as e,w as t,I as o,H as V,n as b,F as n,G as i,$ as r,V as B,t as x,u as T}from"./index-5ee1411a.js";import{V as h,a as k}from"./VToolbar-55156e00.js";import{a as w,V as l}from"./VTabs-4e66fe57.js";import"./transition-cd9cc606.js";import"./index-a55adddd.js";import"./VImg-71612e97.js";import"./VBtn-1e45aba2.js";import"./forwardRefs-2fb8bd5a.js";import"./VProgressCircular-4762adb7.js";import"./resizeObserver-5499429a.js";import"./scopeId-4c4b48c5.js";import"./VSlideGroup-b93846bd.js";const j=v({__name:"Settings",setup(y){const u=f(),m=g(()=>{var s,a;return(s=u.currentRoute.value.name)!=null&&s.toString().includes("forecast")?"forecast":(a=u.currentRoute.value.name)!=null&&a.toString().includes("core")?"core":"devices"});return(s,a)=>{const p=b("router-view");return c(),_("div",null,[e(h,{color:"transparent",title:o(B)("bp4")?o(r)("app.settings"):""},{append:t(()=>[e(w,{"model-value":m.value,"align-tabs":"end",height:"100%"},{default:t(()=>[e(l,{value:"devices",to:{name:"devicessettings"}},{default:t(()=>[n(i(o(r)("settings.devices")),1)]),_:1}),e(l,{value:"forecast",to:{name:"forecastsettings"}},{default:t(()=>[n(i(o(r)("settings.forecast")),1)]),_:1}),e(l,{value:"core",to:{name:"coresettings"}},{default:t(()=>[n(i(o(r)("settings.core")),1)]),_:1})]),_:1},8,["model-value"])]),_:1},8,["title"]),e(k),a[0]||(a[0]=V("div",{style:{height:"15px"}},null,-1)),e(p,null,{default:t(({Component:d})=>[(c(),x(T(d)))]),_:1})])}}});export{j as default};
