const s=function(r,t){return r==null?"":r==0?"0 "+t:Math.abs(r)<10?Math.abs(r)<1&&t=="kWh"?(r*1e3).toFixed(0)+" Wh":r.toFixed(1)+" "+t:r.toFixed(0)+" "+t};function o(r,t){return String(r).padStart(t,"0")}const e=function(r){let t=r;const n=Math.floor(t/3600);t-=n*3600;const f=Math.floor(t/60);t-=f*60;const i=Math.floor(t);return o(n,2)+":"+o(f,2)+":"+o(i,2)};export{e as a,s as f};
