if(!self.define){let s,e={};const l=(l,r)=>(l=new URL(l+".js",r).href,e[l]||new Promise((e=>{if("document"in self){const s=document.createElement("script");s.src=l,s.onload=e,document.head.appendChild(s)}else s=l,importScripts(l),e()})).then((()=>{let s=e[l];if(!s)throw new Error(`Module ${l} didn’t register its module`);return s})));self.define=(r,i)=>{const n=s||("document"in self?document.currentScript.src:"")||location.href;if(e[n])return;let u={};const a=s=>l(s,n),o={module:{uri:n},exports:u,require:a};e[n]=Promise.all(r.map((s=>o[s]||a(s)))).then((s=>(i(...s),u)))}}define(["./workbox-e3490c72"],(function(s){"use strict";self.addEventListener("message",(s=>{s.data&&"SKIP_WAITING"===s.data.type&&self.skipWaiting()})),s.precacheAndRoute([{url:"assets/_plugin-vue_export-helper-c27b6911.js",revision:null},{url:"assets/CoreConfigs-14a9626a.js",revision:null},{url:"assets/Default-adc91128.js",revision:null},{url:"assets/Default-bfa25402.css",revision:null},{url:"assets/Devices-ce90087c.css",revision:null},{url:"assets/Devices-cecfdbf5.js",revision:null},{url:"assets/EditDeviceConfig-0eaade00.js",revision:null},{url:"assets/Forecast-5b3918ba.js",revision:null},{url:"assets/Forecast-f32f6347.js",revision:null},{url:"assets/forwardRefs-2fb8bd5a.js",revision:null},{url:"assets/Home-a99c5bad.js",revision:null},{url:"assets/index-5a502f9f.js",revision:null},{url:"assets/index-5ee1411a.js",revision:null},{url:"assets/index-8a0a02fb.css",revision:null},{url:"assets/index-a55adddd.js",revision:null},{url:"assets/PowerFlowCard-bb637685.js",revision:null},{url:"assets/PowerFlowCard-bf65823d.css",revision:null},{url:"assets/RawData-0bffaabf.js",revision:null},{url:"assets/RawData-bc9fc912.css",revision:null},{url:"assets/resizeObserver-5499429a.js",revision:null},{url:"assets/scopeId-4c4b48c5.js",revision:null},{url:"assets/SessionLog-02b7275d.css",revision:null},{url:"assets/SessionLog-1c8593bb.js",revision:null},{url:"assets/Settings-fd2de6a5.js",revision:null},{url:"assets/Statistics-e2f5c4e1.js",revision:null},{url:"assets/transition-cd9cc606.js",revision:null},{url:"assets/transition-ff063a6c.css",revision:null},{url:"assets/utils-6f3c77d7.js",revision:null},{url:"assets/VBtn-1e45aba2.js",revision:null},{url:"assets/VBtn-cf339980.css",revision:null},{url:"assets/VCard-8ba7cfc2.js",revision:null},{url:"assets/VCard-cd64b26e.css",revision:null},{url:"assets/VImg-71612e97.js",revision:null},{url:"assets/VImg-8f58aea4.css",revision:null},{url:"assets/VOverlay-1134342d.js",revision:null},{url:"assets/VOverlay-176f17d1.css",revision:null},{url:"assets/VProgressCircular-4762adb7.js",revision:null},{url:"assets/VProgressCircular-4a58d9a5.css",revision:null},{url:"assets/VSelect-99b378ff.css",revision:null},{url:"assets/VSelect-c424a144.js",revision:null},{url:"assets/VSlideGroup-b93846bd.js",revision:null},{url:"assets/VSlideGroup-f07ad3cd.css",revision:null},{url:"assets/VTable-3f843f69.js",revision:null},{url:"assets/VTable-800f6bd4.css",revision:null},{url:"assets/VTabs-4e66fe57.js",revision:null},{url:"assets/VTabs-8212064b.css",revision:null},{url:"assets/VTextField-896809fd.css",revision:null},{url:"assets/VTextField-a8ac4f44.js",revision:null},{url:"assets/VToolbar-55156e00.js",revision:null},{url:"assets/VToolbar-f5f1405e.css",revision:null},{url:"assets/workbox-window.prod.es5-5ffdab76.js",revision:null},{url:"index.html",revision:"2499f0236d3adc770f915eea509bdab2"},{url:"apple-touch-icon.png",revision:"ec84610d7d85b67822bcb8a7f5114354"},{url:"pwa-192x192.png",revision:"568e4ca3a35484f7b1cd02882e9e8ac0"},{url:"pwa-512x512.png",revision:"1e5320b35c3f539c43a9132b901bb0e9"},{url:"robots.txt",revision:"f77c87f977e0fcce05a6df46c885a129"},{url:"manifest.webmanifest",revision:"14575172cc64b2172ce0f6fac9b45006"}],{}),s.cleanupOutdatedCaches(),s.registerRoute(new s.NavigationRoute(s.createHandlerBoundToURL("index.html")))}));
