import{aI as f,r as i,am as a,j as R,P as c,aA as g}from"./index-5ee1411a.js";function v(s){let u=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"content";const o=f(),t=i();if(a){const n=new ResizeObserver(e=>{s==null||s(e,n),e.length&&(u==="content"?t.value=e[0].contentRect:t.value=e[0].target.getBoundingClientRect())});R(()=>{n.disconnect()}),c(()=>o.el,(e,r)=>{r&&(n.unobserve(r),t.value=void 0),e&&n.observe(e)},{flush:"post"})}return{resizeRef:o,contentRect:g(t)}}export{v as u};
