import{p as t,s as c,c as u,P as r,g as d}from"./index-5ee1411a.js";const l=t({eager:Boolean},"lazy");function p(o,e){const a=c(!1),s=u(()=>a.value||o.eager||e.value);r(e,()=>a.value=!0);function n(){o.eager||(a.value=!1)}return{isBooted:a,hasContent:s,onAfterLeave:n}}function m(){const e=d("useScopeId").vnode.scopeId;return{scopeId:e?{[e]:""}:void 0}}export{p as a,l as m,m as u};
